@@ -7,6 +7,7 @@
 #  20-Jul-2021 jdw  Make this provider a subclass of StashableBase
 #   3-Jan-2022 dwp  Update data loading methods to address recent changes in source NCBO ATC files
 #  25-Jul-2022 dwp  Revert last change - source NCBO ATC files were updated again to restore previous format
+#  27-Jul-2022 dwp  Adapt to possible naming schemes for class IDs (may be identified with "ATC" or "UATC")
 ##
 """
   Extract ATC term descriptions from NCBO ATC flat files.
@@ -128,13 +129,22 @@ class AtcProvider(StashableBase):
         Example public data set from BioPortal -
         Class ID,Preferred Label,Synonyms,Definitions,Obsolete,CUI,Semantic Types,Parents,ATC LEVEL,Is Drug Class,Semantic type UMLS property
 
+        http://purl.bioontology.org/ontology/ATC/A03AX13,silicones,,,false,C0037114,http://purl.bioontology.org/ontology/STY/T109|http://purl.bioontology.org/ontology/STY/T122,http://purl.bioontology.org/ontology/UATC/A03AX,5,,http://purl.bioontology.org/ontology/STY/T109|http://purl.bioontology.org/ontology/STY/T122
+        http://purl.bioontology.org/ontology/ATC/J01DB07,cefatrizine,,,false,C0007545,http://purl.bioontology.org/ontology/STY/T195|http://purl.bioontology.org/ontology/STY/T109,http://purl.bioontology.org/ontology/UATC/J01DB,5,,http://purl.bioontology.org/ontology/STY/T195|http://purl.bioontology.org/ontology/STY/T109
+
+        Occasionally changes from "ATC" to "UATC", so capture these too:
         http://purl.bioontology.org/ontology/UATC/A03AX13,silicones,,,false,C0037114,http://purl.bioontology.org/ontology/STY/T109|http://purl.bioontology.org/ontology/STY/T122,http://purl.bioontology.org/ontology/UATC/A03AX,5,,http://purl.bioontology.org/ontology/STY/T109|http://purl.bioontology.org/ontology/STY/T122
         http://purl.bioontology.org/ontology/UATC/J01DB07,cefatrizine,,,false,C0007545,http://purl.bioontology.org/ontology/STY/T195|http://purl.bioontology.org/ontology/STY/T109,http://purl.bioontology.org/ontology/UATC/J01DB,5,,http://purl.bioontology.org/ontology/STY/T195|http://purl.bioontology.org/ontology/STY/T109
         """
         nD = {}
-        ns = "http://purl.bioontology.org/ontology/UATC/"
+        nsATC = "http://purl.bioontology.org/ontology/ATC/"
+        nsUATC = "http://purl.bioontology.org/ontology/UATC/"
         for rD in atcL:
-            if ns not in rD["Class ID"]:
+            if nsATC in rD["Class ID"]:
+                ns = nsATC
+            elif nsUATC in rD["Class ID"]:
+                ns = nsUATC
+            else:
                 continue
             idCode = rD["Class ID"].replace(ns, "")
             name = rD["Preferred Label"]
@@ -148,9 +158,14 @@ class AtcProvider(StashableBase):
     def __extractHierarchy(self, atcL):
         """ """
         pD = {}
-        ns = "http://purl.bioontology.org/ontology/UATC/"
+        nsATC = "http://purl.bioontology.org/ontology/ATC/"
+        nsUATC = "http://purl.bioontology.org/ontology/UATC/"
         for rD in atcL:
-            if ns not in rD["Class ID"]:
+            if nsATC in rD["Class ID"]:
+                ns = nsATC
+            elif nsUATC in rD["Class ID"]:
+                ns = nsUATC
+            else:
                 continue
             idCode = rD["Class ID"].replace(ns, "")
             pIdCode = rD["Parents"].replace(ns, "")
